@@ -168,11 +168,11 @@ def train(model, train_dataset, val_dataset, model_pretrained=None):
                                 epochs=FLAGS.epochs,
                                 callbacks=callbacks,
                                 validation_data=val_dataset)
-        except KeyboardInterrupt:
-            plot_history(history, save_path=os_path.join(os_path.dirname(FLAGS.weights),
-                                                         f"{datetime.datetime.now().strftime('%Y%m%d-%H%M')}.png"))
         except Exception as e:
             raise e
+        finally:
+            plot_history(history, save_path=os_path.join(os_path.dirname(FLAGS.weights),
+                                                         f"{datetime.datetime.now().strftime('%Y%m%d-%H%M')}.png"))
 
 
 @logger.catch(reraise=True)
